@@ -140,7 +140,7 @@ thispid=$$
 mkdir tmp$thispid
 cd tmp$thispid
 echo Logging in as \"$username\"
-wget $wgetopts --save-cookies=cookies --post-data="username=$username&password=$password" "http://iphone.tvcatchup.com/?login=1" -O login.html
+wget $wgetopts --keep-session-cookies --save-cookies=cookies --post-data="username=$username&password=$password" "http://iphone.tvcatchup.com/?login=1" -O login.html
 if [ "`cat login.html`" == "success" ]
         then
         echo Login OK
